@@ -146,8 +146,6 @@ typedef unsigned int curl_prot_t;
 
 #include "curlx/timeval.h"
 
-#include <curl/curl.h>
-
 #include "http_chunks.h" /* for the structs and enum stuff */
 #include "hostip.h"
 #include "hash.h"
@@ -179,7 +177,6 @@ typedef CURLcode (Curl_recv)(struct Curl_easy *data,   /* transfer */
 #include "smtp.h"
 #include "ftp.h"
 #include "file.h"
-#include "vssh/ssh.h"
 #include "http.h"
 #include "rtsp.h"
 #include "smb.h"
